torchtt.errors API documentation
Description: Contains the errors used in the `torchtt` package.

# Module `torchtt.errors`

Contains the errors used in the `torchtt` package.

Expand source code

    """
    Contains the errors used in the `torchtt` package.
    """
    class ShapeMismatch(Exception):
        """The shape of the tensors does not match.

        This means that the inputs  have shapes that do not match.
        """
        pass

    class RankMismatch(Exception):
        """The TT-ranks do not match.

        This means that the inputs shapes that do not match.
        """
        pass

    class IncompatibleTypes(Exception):
        """The function arguments are not compatible.

        Usually means that a TT matrix was passed as argument instead of a TT tensor (or viceversa).
        """
        pass

    class InvalidArguments(Exception):
        """The arguments are not valid.

        The arguments passed are not of valid type.
        """
        pass

## Classes

`class IncompatibleTypes (*args, **kwargs)`

  The function arguments are not compatible.

  Usually means that a TT matrix was passed as argument instead of a TT tensor (or viceversa).

  Expand source code

      class IncompatibleTypes(Exception):
          """The function arguments are not compatible.

          Usually means that a TT matrix was passed as argument instead of a TT tensor (or viceversa).
          """
          pass

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class InvalidArguments (*args, **kwargs)`

  The arguments are not valid.

  The arguments passed are not of valid type.

  Expand source code

      class InvalidArguments(Exception):
          """The arguments are not valid.

          The arguments passed are not of valid type.
          """
          pass

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class RankMismatch (*args, **kwargs)`

  The TT-ranks do not match.

  This means that the inputs shapes that do not match.

  Expand source code

      class RankMismatch(Exception):
          """The TT-ranks do not match.

          This means that the inputs shapes that do not match.
          """
          pass

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class ShapeMismatch (*args, **kwargs)`

  The shape of the tensors does not match.

  This means that the inputs have shapes that do not match.

  Expand source code

      class ShapeMismatch(Exception):
          """The shape of the tensors does not match.

          This means that the inputs  have shapes that do not match.
          """
          pass

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException